@@ -125,7 +125,6 @@ gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms
 	AtomList = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE);
 	GtkTreeView* tree = (GtkTreeView*)glade_xml_get_widget(xml, "atomslist");
 	Selection = gtk_tree_view_get_selection(tree);
-	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
 	gtk_tree_view_set_model(tree, GTK_TREE_MODEL(AtomList));
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -204,12 +203,17 @@ gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms
 	RadiusMenu = (GtkOptionMenu*) glade_xml_get_widget(xml, "radius-menu");
 	g_signal_connect (G_OBJECT (RadiusMenu), "changed", G_CALLBACK (on_radius_index_changed), this);
 	AtomR = (GtkEntry*) glade_xml_get_widget(xml, "atomr");
+	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
 	m_RadiusType = m_Charge = 0;
 	m_Radii = NULL;
 	m_Radius.type = GCU_RADIUS_UNKNOWN;
 	m_Radius.cn = -1;
 	m_Radius.spin = GCU_N_A_SPIN;
+#ifdef GCU_0_6
+	m_Radius.value.value = 0.;
+#else
 	m_Radius.value = 0.;
+#endif
 	m_Radius.scale = "custom";
 	PopulateRadiiMenu();
 }
@@ -217,6 +221,7 @@ gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms
 gcAtomsDlg::~gcAtomsDlg()
 {
 	g_array_free(m_Atoms, false);
+	g_object_unref (AtomList);
 	m_pDoc->RemoveDialog(this);
 }
 
@@ -230,7 +235,11 @@ bool gcAtomsDlg::Apply()
 			gnome_color_picker_get_d(AtomColor, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Red, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Green, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Blue, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Alpha);
 		}
 		else g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).CustomColor = false;
+#ifdef GCU_0_6
+		if ((!GetNumber(AtomR, &(m_Radius.value.value), gccMin, 0)) || (m_Radius.value.value == 0.0))
+#else
 		if ((!GetNumber(AtomR, &(m_Radius.value), gccMin, 0)) || (m_Radius.value == 0.0))
+#endif
 		{
 		}
 		else g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Radius = m_Radius;
@@ -268,7 +277,11 @@ void gcAtomsDlg::AtomAdd()
 	s.x = s.y =s.z = 0.0;
 	gnome_color_picker_get_d(AtomColor, &s.Red, &s.Green, &s.Blue, &s.Alpha);
 	s.CustomColor = gtk_toggle_button_get_active(CustomColor);
+#ifdef GCU_0_6
+	GetNumber(AtomR, &m_Radius.value.value);
+#else
 	GetNumber(AtomR, &m_Radius.value);
+#endif
 	s.Radius = m_Radius;
 	g_array_append_vals(m_Atoms, &s, 1);
 	gtk_list_store_append (AtomList, &iter);
@@ -321,7 +334,11 @@ void gcAtomsDlg::AtomSelect(GtkTreeSelection *Selection)
 			gnome_color_picker_get_d(AtomColor, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Red, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Green, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Blue, &g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Alpha);
 		}
 		else g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).CustomColor = false;
+#ifdef GCU_0_6
+		if ((!GetNumber(AtomR, &(m_Radius.value.value), gccMin, 0)) || (m_Radius.value.value == 0.0))
+#else
 		if ((!GetNumber(AtomR, &(m_Radius.value), gccMin, 0)) || (m_Radius.value == 0.0))
+#endif
 		{
 		}
 		else g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Radius = m_Radius;
@@ -350,7 +367,11 @@ void gcAtomsDlg::AtomSelect(GtkTreeSelection *Selection)
 		{
 			m_Radius = r;
 			char buf[20];
+#ifdef GCU_0_6
+			g_snprintf(buf, sizeof(buf), "%g", m_Radius.value.value);
+#else
 			g_snprintf(buf, sizeof(buf), "%g", m_Radius.value);
+#endif
 			gtk_entry_set_text(AtomR, buf);
 			gtk_option_menu_set_history(RadiusMenu, 0);
 		}
@@ -489,7 +510,11 @@ void gcAtomsDlg::SetRadiusIndex(int index)
 	{
 		m_Radius = *(m_Radii[i]);
 		char buf[20];
+#ifdef GCU_0_6
+		g_snprintf(buf, sizeof(buf), "%g", m_Radius.value.value);
+#else
 		g_snprintf(buf, sizeof(buf), "%g", m_Radius.value);
+#endif
 		gtk_entry_set_text(AtomR, buf);
 	}
 	else
@@ -533,7 +558,11 @@ void gcAtomsDlg::PopulateRadiiMenu()
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 	if (radius) while (*radius)
 	{
+#ifdef GCU_0_6
+		if (((*radius)->type != m_RadiusType) ||  ((*radius)->charge != m_Charge) || ((*radius)->value.value <= 0.))
+#else
 		if (((*radius)->type != m_RadiusType) ||  ((*radius)->charge != m_Charge) || ((*radius)->value <= 0.))
+#endif
 		{
 			radius++;
 			i++;
