@@ -4,9 +4,9 @@
  * Gnome Crystal
  * cleavagesdlg.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -82,7 +82,6 @@ gcCleavagesDlg::gcCleavagesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/gla
 	FixedBtn = GTK_TOGGLE_BUTTON(glade_xml_get_widget(xml, "fixed"));
 	GtkTreeView* tree = (GtkTreeView*)glade_xml_get_widget(xml, "cleavageslist");
 	Selection = gtk_tree_view_get_selection(tree);
-	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
 	CleavageList = gtk_list_store_new(5, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_UINT, G_TYPE_BOOLEAN);
 	gtk_tree_view_set_model(tree, GTK_TREE_MODEL(CleavageList));
 	GtkCellRenderer *renderer;
@@ -148,12 +147,14 @@ gcCleavagesDlg::gcCleavagesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/gla
 				  3, s.planes,
 				  -1);
 	}
+	g_signal_connect(G_OBJECT(Selection), "changed", GTK_SIGNAL_FUNC(on_select), this);
 	if (!m_Cleavages->len)gtk_widget_set_sensitive(DeleteAllBtn, false);
 }
 
 gcCleavagesDlg::~gcCleavagesDlg()
 {
 	g_array_free(m_Cleavages, false);
+	g_object_unref (CleavageList);
 	m_pDoc->RemoveDialog(this);
 }
 
@@ -170,7 +171,7 @@ bool gcCleavagesDlg::Apply()
 	
 	CrystalCleavage* c;
 	struct CleavageStruct* s;
-	for (int i = 0; i  < m_Cleavages->len; i++)
+	for (int i = 0; i  < (int) m_Cleavages->len; i++)
 	{
 		s = &g_array_index(m_Cleavages, struct CleavageStruct, i);
 		if (!s->planes || ((!s->h) && (!s->k) && (!s->l))) continue;
