@@ -230,10 +230,7 @@ void gcDocument::SetTitle(const gchar* title)
 void gcDocument::Save()
 {
 	if (!m_filename) return;
-	gchar buf[256];
-	xmlDocPtr xml;
-	xmlNodePtr node;
-	char *old_num_locale;
+	xmlDocPtr xml = NULL;
 
 	try
 	{
@@ -247,15 +244,13 @@ void gcDocument::Save()
 	catch (int num)
 	{
 		xmlFreeDoc(xml);
-		setlocale(LC_NUMERIC, old_num_locale);
-		g_free(old_num_locale);
 		Error(SAVE);
 	}
 }
 
 void gcDocument::Error(int num)
 {
-	gchar *mess;
+	gchar *mess = NULL;
 	GtkWidget* message;
 	switch (num)
 	{
@@ -281,7 +276,7 @@ void gcDocument::Error(int num)
 
 bool gcDocument::Load(const gchar* filename)
 {
-	xmlDocPtr xml;
+	xmlDocPtr xml = NULL;
 	gchar *oldfilename, *oldtitle;
 	if (m_filename) oldfilename = g_strdup(m_filename);
 	else oldfilename = NULL;
@@ -573,6 +568,7 @@ void gcDocument::OnExportVRML(const gchar* FileName, gcView* pView)
 
 gcView *gcDocument::GetNewView()
 {
+	return NULL;
 }
 
 void gcDocument::SetDirty()
@@ -622,7 +618,7 @@ bool gcDocument::VerifySaved()
 		{
 			if (m_filename == NULL)
 			{
-				gcFileSel* FileSel = new gcFileSel(_("Save model as..."), do_save_as, true, ".gcrystal", (gcView*)m_Views.front(), true);
+				new gcFileSel(_("Save model as..."), do_save_as, true, ".gcrystal", (gcView*)m_Views.front(), true);
 				while (((gcView*)(m_Views.front()))->IsLocked())
 					if (gtk_events_pending()) gtk_main_iteration();
 			}
